@@ -34,9 +34,18 @@ class PaymentState(enum.Enum):
 
 
 class PaymentTypes(enum.Enum):
+    """
+    Supported payment types
+
+    Used as short-name in type-ids like ``s-crd-abc456def789``
+
+    source: https://github.com/unzerdev/java-sdk/blob/main/src/main/java/com/unzer/payment/paymenttypes/PaymentTypeEnum.java  # noqa: E501
+    """
     CARD = "crd"
+    CLICK_TO_PAY = "ctp"
     EPS = "eps"
     GIROPAY = "gro"
+    GOOGLE_PAY = "gop"
     IDEAL = "idl"
     INVOICE = "ivc"
     INVOICE_GUARANTEED = "ivg"  # deprecated
@@ -46,23 +55,63 @@ class PaymentTypes(enum.Enum):
     PREPAYMENT = "ppy"
     PRZELEWY24 = "p24"
     SEPA_DIRECT_DEBIT = "sdd"
-    SEPA_DIRECT_DEBIT_GUARANTEED = "ddg"
-    SEPA_DIRECT_DEBIT_SECURED = "dds"
+    SEPA_DIRECT_DEBIT_GUARANTEED = "ddg"  # deprecated
+    SEPA_DIRECT_DEBIT_SECURED = "dds"  # deprecated
     SOFORT = "sft"
     PIS = "pis"
     ALIPAY = "ali"
     WECHATPAY = "wcp"
-    APPLEPAY = "apl"
+    APPLE_PAY = "apl"
     HIRE_PURCHASE_RATE_PLAN = "hdd"
-    INSTALLMENT_SECURED_RATE_PLAN = "ins"
+    INSTALLMENT_SECURED_RATE_PLAN = "ins"  # deprecated
     BANCONTACT = "bct"
     PF_CARD = "pfc"
     PF_EFINANCE = "pfe"
     UNZER_PAYLATER_INVOICE = "piv"
     KLARNA = "kla"
+    PAYLATER_INSTALLMENT = "pit"
+    PAYLATER_DIRECT_DEBIT = "pdd"
+    TWINT = "twt"
+    OPEN_BANKING = "obp"
     UNKNOWN = "unknown"
 
 
+class PaymentMethodTypes(enum.Enum):
+    """
+    Full name of supported payment types
+
+    Used as name in URLs like ``types/<name>/``
+
+    source: https://github.com/unzerdev/integration-core/blob/master/src/BusinessLogic/Domain/PaymentMethod/Enums/PaymentMethodTypes.php  # noqa: E501
+    """
+    ALI_PAY = "alipay"
+    APPLE_PAY = "applepay"
+    BANCONTACT = "bancontact"
+    CARD = "card"
+    GIROPAY = "giropay"
+    GOOGLE_PAY = "googlepay"
+    IDEAL = "ideal"
+    KLARNA = "klarna"
+    PAYPAL = "paypal"
+    PAYU = "payu"
+    PRZELEWY24 = "przelewy24"
+    POST_FINANCE_CARD = "post-finance-card"
+    POST_FINANCE_EFINANCE = "post-finance-efinance"
+    SOFORT = "sofort"
+    TWINT = "twint"
+    UNZER_DIRECT_DEBIT = "sepa-direct-debit"
+    DIRECT_DEBIT_SECURED = "paylater-direct-debit"
+    UNZER_INSTALLMENT = "paylater-installment"
+    UNZER_INVOICE = "paylater-invoice"
+    UNZER_PREPAYMENT = "prepayment"
+    WECHATPAY = "wechatpay"
+    EPS = "EPS"
+    DIRECT_BANK_TRANSFER = "openbanking-pis"
+    CLICK_TO_PAY = "clicktopay"
+
+
+# TODO: Combine PaymentMethodTypes and PaymentTypes in a dataclass to have their mapping too?
+
 paymentUrlRe = re.compile(
     r"^https://api.unzer.com/v1/"
     r"(?P<operation>[a-z]+)/(?P<paymentId>[\w-]+)"  # payments/{codeOrOrderId}
@@ -93,9 +142,6 @@ class PaymentGetResponse(BaseModel):
             payPageId=None,
             linkPayId=None,
             typeId=None,
-
-            client: "UnzerClient" = None,
-
             **kwargs
     ):
         """Create a new PaymentGetResponse.
@@ -142,10 +188,8 @@ class PaymentGetResponse(BaseModel):
         :type linkPayId: str
         :param typeId: (optional) Id of the types Resource that is to be used for this transaction.
         :type typeId: str
-
-        :param client: (optional) The client instance.
-        :type client: unzer.client.UnzerClient
         """
+        super().__init__(**kwargs)
         if transactions is None:
             transactions = []
         state = PaymentState(state)
@@ -175,8 +219,6 @@ class PaymentGetResponse(BaseModel):
         self.linkPayId = linkPayId  # type: str
         self.typeId = typeId  # type: str
 
-        self._client: "UnzerClient" = client
-
     def serialize(self):
         raise NotImplementedError("No serialisation for response models.")
 
@@ -268,6 +310,7 @@ class PaymentTransaction(BaseModel):
         :param amount: (optional)
         :type amount: float
         """
+        super().__init__(**kwargs)
         self.paymentId = paymentId  # type:str
         self.transactionId = transactionId  # type:str
         self.participantId = participantId  # type:str
@@ -323,7 +366,6 @@ class PaymentRequest(BaseModel):
             metadataId=None,
             basketId=None,
 
-            client=None,
             **kwargs
     ):
         """Create a new PaymentRequest.
@@ -360,10 +402,8 @@ class PaymentRequest(BaseModel):
         :type metadataId: str
         :param basketId: (optional) Basket ID used for this transaction.
         :type basketId: str
-
-        :param client: (optional) The client instance.
-        :type client: unzer.client.UnzerClient
         """
+        super().__init__(**kwargs)
         if not isinstance(card3ds, (bool, NoneType)):
             raise TypeError("Invalid value %r for card3ds. Must be a boolean or None." % card3ds)
         self.paymentType = paymentType  # type:PaymentType
@@ -381,8 +421,6 @@ class PaymentRequest(BaseModel):
         self.metadataId = metadataId  # type: str
         self.basketId = basketId  # type: str
 
-        self._client = client  # type: unzer.client.UnzerClient
-
     def serialize(self):
         data = {
             "amount": self.amount,
@@ -498,6 +536,7 @@ class PaymentResponse(BaseModel):
         :param processing: (optional)
         :type processing: PaymentResponseMetadata
         """
+        super().__init__(**kwargs)
         self.transactionId = transactionId  # type:str
         self.isSuccess = isSuccess  # type:bool
         self.isPending = isPending  # type:bool
@@ -528,7 +567,7 @@ class PaymentResponse(BaseModel):
         raise NotImplementedError("No serialisation for response models.")
 
     @classmethod
-    def fromDict(cls, data):
+    def fromDict(cls, data: dict, client: "UnzerClient") -> t.Self:
         data = data.copy()
         data["transactionId"] = data["id"]
         data["isSuccess"] = parseBool(data["isSuccess"])
@@ -552,7 +591,16 @@ class PaymentResponse(BaseModel):
         data["payPageId"] = data["resources"].get("payPageId") or None
         data["linkPayId"] = data["resources"].get("linkPayId") or None
         data["typeId"] = data["resources"].get("typeId") or None
-        return cls(**data)
+        return cls(**data, client=client)
+
+    def charge(self, amount: float) -> "PaymentResponse":
+        req_kwargs = self.__dict__.copy()
+        paymentTypeName = PaymentGetResponse.getPaymentTypeFromTypeId(self.typeId)
+        req_kwargs["paymentType"] = PaymentType.construct(paymentTypeName)(self.typeId)
+        req_kwargs["amount"] = amount
+        logging.debug("req_kwargs = %r", req_kwargs)
+        req = PaymentRequest(**req_kwargs)
+        return self._client.charge(req)
 
 
 class PaymentResponseMetadata(BaseModel):
@@ -562,6 +610,7 @@ class PaymentResponseMetadata(BaseModel):
             identification=None,
             iban=None,
             bic=None,
+            bank=None,
             externalOrderId=None,
             zgReferenceId=None,
             traceId=None,
@@ -588,6 +637,10 @@ class PaymentResponseMetadata(BaseModel):
         :param bic: (optional) String Bic of the merchant for prepayment or invoice.
             In the case of a direct debit, this value contains the customer Bic.
         :type bic: str
+        :param bank: (optional)
+            Bank of the merchant for prepayment or invoice.
+            In the case of a direct debit, this value contains the customer Bank.
+        :type bank: str
         :param externalOrderId: (optional) String External Order Id of installment transaction
             e.g: Hirepurchase, Installment-Secured.
         :type externalOrderId: str
@@ -602,7 +655,7 @@ class PaymentResponseMetadata(BaseModel):
         :type uniqueId: str
         :param shortId: (optional) String User-friendly reference id of the payment system.
         :type shortId: str
-        :param descriptor: (optional) String Descriptor of the merchant for prepayment or invoice.
+        :param descriptor: (optional) String Descriptor of the merchant for prepayment or invoice..
         :type descriptor: str
         :param holder: (optional) String Holder of the merchant for prepayment or invoice.
             In the case of a direct debit, this value contains the customer holder.
@@ -618,10 +671,12 @@ class PaymentResponseMetadata(BaseModel):
             Channel Id(s) of marketplace's participant(s).
         :type participantId: str
         """
+        super().__init__(**kwargs)
         self.creatorId = creatorId  # type:str
         self.identification = identification  # type:str
         self.iban = iban  # type:str
         self.bic = bic  # type:str
+        self.bank = bank  # type:str
         self.externalOrderId = externalOrderId  # type:str
         self.zgReferenceId = zgReferenceId  # type:str
         self.traceId = traceId  # type:str
