@@ -1,15 +1,21 @@
 from .abstract_paymenttype import PaymentType
+from .applepay import Applepay
 from .bancontact import Bancontact
 from .card import Card
+from .googlepay import Googlepay
 from .ideal import Ideal
+from .paylater_invoice import PaylaterInvoice
 from .paypal import PayPal
 from .sofort import Sofort
 
 __all__ = [
     "PaymentType",
+    "Applepay",
     "Bancontact",
     "Card",
+    "Googlepay",
     "Ideal",
+    "PaylaterInvoice",
     "PayPal",
     "Sofort",
 ]
