@@ -1,6 +1,7 @@
-from unzer.model.payment import PaymentTypes
+from unzer.model.payment import PaymentMethodTypes, PaymentTypes
 from .abstract_paymenttype import PaymentType
 
 
 class PayPal(PaymentType):
     method = PaymentTypes.PAYPAL
+    method_name = PaymentMethodTypes.PAYPAL
