@@ -1,6 +1,7 @@
-from unzer.model.payment import PaymentTypes
+from unzer.model.payment import PaymentMethodTypes, PaymentTypes
 from .abstract_paymenttype import PaymentType
 
 
 class Sofort(PaymentType):
     method = PaymentTypes.SOFORT
+    method_name = PaymentMethodTypes.SOFORT
